@@ -106,7 +106,6 @@ struct _GladeProjectPrivate
 	GList       *prev_redo_item;          /* Points to the item previous to the redo items */
 	GHashTable  *widget_names_allocator;  /* hash table with the used widget names */
 	GHashTable  *widget_old_names;        /* widget -> old name of the widget */
-	GtkTooltips *tooltips;
 	
 	GladeCommand *first_modification; /* we record the first modification, so that we
 	                                   * can set "modification" to FALSE when we
@@ -202,9 +201,6 @@ glade_project_dispose (GObject *object)
 	}
 	project->priv->objects = NULL;
 
-	gtk_object_destroy (GTK_OBJECT (project->priv->tooltips));
-	project->priv->tooltips = NULL;
-
 	G_OBJECT_CLASS (glade_project_parent_class)->dispose (object);
 }
 
@@ -489,7 +485,6 @@ glade_project_init (GladeProject *project)
 				       
 	priv->widget_old_names = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify) g_free);
 
-	priv->tooltips = gtk_tooltips_new ();
 	priv->accel_group = NULL;
 
 	priv->resources = g_hash_table_new_full (g_direct_hash, 
@@ -692,7 +687,7 @@ glade_project_class_init (GladeProjectClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_MODIFIED,
 					 g_param_spec_boolean ("modified",
-							       _(""),
+							       "Modified",
 							       _("Whether project has been modified since it was last saved"),
 							       FALSE,
 							       G_PARAM_READABLE));
@@ -952,6 +947,15 @@ glade_project_add_object (GladeProject *project,
 	/* Dont add widgets that are already in the project */
 	if (glade_project_has_object (project, object))
 		return;
+
+	/* Police widget names here (just rename them on the way in the project)
+	 */
+	if (glade_project_get_widget_by_name (project, gwidget->name) != NULL)
+	{ 
+		gchar *name = glade_project_new_widget_name (project, gwidget->name);
+		glade_widget_set_name (gwidget, name);
+		g_free (name);
+	}
 		
 	/* Code body starts here */
 	reentrancy_count++;
@@ -1132,10 +1136,28 @@ glade_project_remove_object (GladeProject *project, GObject *object)
 void
 glade_project_widget_name_changed (GladeProject *project, GladeWidget *widget, const char *old_name)
 {
+	GladeWidget *iter;
+	GList       *l;
 	g_return_if_fail (GLADE_IS_PROJECT (project));
 	g_return_if_fail (GLADE_IS_WIDGET (widget));
 
 	glade_project_release_widget_name (project, widget, old_name);
+
+	/* Police widget names here (just rename them on the way in the project)
+	 */
+	for (l = project->priv->objects; l; l = l->next)
+	{
+		iter = glade_widget_get_from_gobject (l->data);
+		
+		if (widget != iter &&
+		    !strcmp (widget->name, iter->name))
+		{ 
+			gchar *name = glade_project_new_widget_name (project, widget->name);
+			glade_widget_set_name (widget, name);
+			g_free (name);
+		}
+		
+	}
 	
 	g_signal_emit (G_OBJECT (project),
 		       glade_project_signals [WIDGET_NAME_CHANGED],
@@ -1971,6 +1993,8 @@ glade_project_undo_items (GladeProject *project)
 	GladeCommand *cmd;
 	GList   *l;
 
+	g_return_val_if_fail (project != NULL, NULL);
+
 	for (l = project->priv->prev_redo_item; l; l = walk_command (l, FALSE))
 	{
 		cmd = l->data;
@@ -2006,6 +2030,8 @@ glade_project_redo_items (GladeProject *project)
 	GladeCommand *cmd;
 	GList   *l;
 
+	g_return_val_if_fail (project != NULL, NULL);
+
 	for (l = project->priv->prev_redo_item ?
 		     project->priv->prev_redo_item->next :
 		     project->priv->undo_stack;
@@ -2036,19 +2062,6 @@ glade_project_reset_path (GladeProject *project)
 	project->priv->path = (g_free (project->priv->path), NULL);
 }
 
-/**
- * glade_project_get_tooltips:
- * @project: a #GladeProject
- *
- * Returns: a #GtkTooltips object containing all tooltips for @project
- */
-GtkTooltips *
-glade_project_get_tooltips (GladeProject *project)
-{
-	g_return_val_if_fail (GLADE_IS_PROJECT (project), NULL);
-	return project->priv->tooltips;
-}
-
 /**
  * glade_project_set_accel_group:
  * @project: A #GladeProject
