@@ -24,6 +24,16 @@
 #include <config.h>
 #endif
 
+/**
+ * SECTION:glade-signal-editor
+ * @Title: GladeSignalEditor
+ * @Short_Description: An interface to edit signals for a #GladeWidget.
+ *
+ * This isnt really a dockable widget, since you need to access the
+ * #GladeSignalEditor struct's '->main_window' widget, the signal editor
+ * is mostly of interest when implementing a custom object editor.
+ */
+
 #include <string.h>
 #include <glib/gi18n-lib.h>
 
@@ -54,8 +64,8 @@ enum
 	NUM_COLUMNS
 };
 
-#define HANDLER_DEFAULT  _("<Type the signal's handler here>")
-#define USERDATA_DEFAULT _("<Type the object's name here>")
+#define HANDLER_DEFAULT  _("<Type here>")
+#define USERDATA_DEFAULT HANDLER_DEFAULT
 
 static void
 glade_signal_editor_after_toggled (GtkCellRendererToggle *cell,
